Index: Source/core/css/ComputedStyleCSSValueMapping.h |
diff --git a/Source/core/css/LayoutStyleCSSValueMapping.h b/Source/core/css/ComputedStyleCSSValueMapping.h |
similarity index 53% |
rename from Source/core/css/LayoutStyleCSSValueMapping.h |
rename to Source/core/css/ComputedStyleCSSValueMapping.h |
index 61a2a35700d2deb2658e40e92ffe2ffca21d703f..6e86b471667ebf57caac7f4f79989382161c6e38 100644 |
--- a/Source/core/css/LayoutStyleCSSValueMapping.h |
+++ b/Source/core/css/ComputedStyleCSSValueMapping.h |
@@ -2,8 +2,8 @@ |
// Use of this source code is governed by a BSD-style license that can be |
// found in the LICENSE file. |
-#ifndef LayoutStyleCSSValueMapping_h |
-#define LayoutStyleCSSValueMapping_h |
+#ifndef ComputedStyleCSSValueMapping_h |
+#define ComputedStyleCSSValueMapping_h |
#include "core/CSSPropertyNames.h" |
@@ -11,23 +11,23 @@ namespace blink { |
class CSSPrimitiveValue; |
class LayoutObject; |
-class LayoutStyle; |
+class ComputedStyle; |
class ShadowData; |
class ShadowList; |
class StyleColor; |
class Node; |
-class LayoutStyleCSSValueMapping { |
+class ComputedStyleCSSValueMapping { |
public: |
- // FIXME: Resolve computed auto alignment in applyProperty/LayoutStyle and remove this non-const styledNode parameter. |
- static PassRefPtrWillBeRawPtr<CSSValue> get(CSSPropertyID, const LayoutStyle&, const LayoutObject* renderer = nullptr, Node* styledNode = nullptr, bool allowVisitedStyle = false); |
+ // FIXME: Resolve computed auto alignment in applyProperty/ComputedStyle and remove this non-const styledNode parameter. |
+ static PassRefPtrWillBeRawPtr<CSSValue> get(CSSPropertyID, const ComputedStyle&, const LayoutObject* renderer = nullptr, Node* styledNode = nullptr, bool allowVisitedStyle = false); |
private: |
- static PassRefPtrWillBeRawPtr<CSSPrimitiveValue> currentColorOrValidColor(const LayoutStyle&, const StyleColor&); |
- static PassRefPtrWillBeRawPtr<CSSValue> valueForShadowData(const ShadowData&, const LayoutStyle&, bool useSpread); |
- static PassRefPtrWillBeRawPtr<CSSValue> valueForShadowList(const ShadowList*, const LayoutStyle&, bool useSpread); |
- static PassRefPtrWillBeRawPtr<CSSValue> valueForFilter(const LayoutStyle&); |
+ static PassRefPtrWillBeRawPtr<CSSPrimitiveValue> currentColorOrValidColor(const ComputedStyle&, const StyleColor&); |
+ static PassRefPtrWillBeRawPtr<CSSValue> valueForShadowData(const ShadowData&, const ComputedStyle&, bool useSpread); |
+ static PassRefPtrWillBeRawPtr<CSSValue> valueForShadowList(const ShadowList*, const ComputedStyle&, bool useSpread); |
+ static PassRefPtrWillBeRawPtr<CSSValue> valueForFilter(const ComputedStyle&); |
}; |
} // namespace blink |
-#endif // LayoutStyleCSSValueMapping_h |
+#endif // ComputedStyleCSSValueMapping_h |